==> ejc-salary-impl-3.0.0-20250622.231317-149-sources.jar: com/ejianc/business/report/controller/SalaryListVWController.java <==
package com.ejianc.business.report.controller;

import java.io.Serializable;

import com.ejianc.business.financeintegration.PMSalary.api.IPMSalarySystemApi;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzDetailVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.report.bean.SalaryListVWEntity;
import com.ejianc.business.report.service.ISalaryListVWService;
import com.ejianc.business.report.vo.SalaryListVWVO;

/**
 * 工资汇总表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("salaryListVW")
public class SalaryListVWController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private IPMSalarySystemApi salarySystemApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISalaryListVWService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SalaryListVWVO> saveOrUpdate(@RequestBody SalaryListVWVO saveOrUpdateVO) {
    	SalaryListVWEntity entity = BeanMapper.map(saveOrUpdateVO, SalaryListVWEntity.class);
    	service.saveOrUpdate(entity, false);
    	SalaryListVWVO vo = BeanMapper.map(entity, SalaryListVWVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SalaryListVWVO> queryDetail(Long id) {
    	SalaryListVWEntity entity = service.selectById(id);
    	SalaryListVWVO vo = BeanMapper.map(entity, SalaryListVWVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SalaryListVWVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SalaryListVWVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SalaryListVWVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SalaryListVWVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("detailEmployeeName");
        fuzzyFields.add("detailEmployeeCode");
        fuzzyFields.add("orgName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        if (param.getParams().containsKey("month")){
            String month = param.getParams().get("month").getValue().toString();
            String[] split = month.split(",");
            split[0] = split[0] + "-01";
            split[1] = split[1] + "-01";
            param.getParams().put("month",new Parameter(QueryParam.BETWEEN,split[0]+","+split[1]));
        }else if (param.getParams().containsKey("period")){
            String month = param.getParams().get("period").getValue().toString();
            String[] split = month.split(",");
            split[0] = split[0] + "-01";
            split[1] = split[1] + "-01";
            param.getParams().put("period",new Parameter(QueryParam.BETWEEN,split[0]+","+split[1]));
        }else {
            return CommonResponse.error("请在筛选条件中选择时间！");
        }
        IPage<SalaryListVWEntity> page = service.queryPage(param,false);
        IPage<SalaryListVWVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryListVWVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("detailEmployeeName");
        fuzzyFields.add("detailEmployeeCode");
        fuzzyFields.add("orgName");

        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SalaryListVWEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("SalaryListVW-export.xlsx", beans, response);
    }
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/excelBankExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelBankExport(@RequestBody QueryParam param, HttpServletResponse response) {

        if(!param.getParams().containsKey("bankName")) {
            throw new BusinessException("请先筛选相同开户行类别后再进行导出！");
        }
            CommonResponse<JSONObject> commonResponse = salarySystemApi.queryGZList(param);
        if(!commonResponse.isSuccess()){
            throw new BusinessException("查询工资明细失败!");
        }
        JSONObject responseData = commonResponse.getData();
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", responseData.get("records"));
        String bankName = param.getParams().get("bankName").getValue().toString();
        if(bankName.contains("浦东")){
            ExcelExport.getInstance().export("银企直连（代付）-浦发模版.xlsm", beans, response);
        }
        if(bankName.contains("农业")){
            ExcelExport.getInstance().export("银企直连（代付）-农行工资模版.xlsm", beans, response);
        }
        if(bankName.contains("郑州银行")){
            ExcelExport.getInstance().export("银企直连（代付）-郑州银行模版.xlsm", beans, response);
        }
        if(bankName.contains("交通银行")){
            ExcelExport.getInstance().export("网银-交行代发薪资模版.xls", beans, response);
        }
        if(bankName.contains("建设银行")){
            ExcelExport.getInstance().export("网银-交行代发薪资模版.xls", beans, response);
        }
        ExcelExport.getInstance().export("SalaryListVW-export.xlsx", beans, response);

    }
    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refSalaryListVWData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SalaryListVWVO>> refSalaryListVWData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SalaryListVWEntity> page = service.queryPage(param,false);
        IPage<SalaryListVWVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryListVWVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/querySbList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> querySbList(@RequestBody QueryParam param) {
        return salarySystemApi.queryList(param);
    }
    @RequestMapping(value = "/queryGzList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryGzList(@RequestBody QueryParam param) {
        return salarySystemApi.queryGZList(param);
    }


}

==> ejc-salary-impl-3.0.0-20251111.034436-194-sources.jar: com/ejianc/business/report/controller/SalaryListVWController.java <==
package com.ejianc.business.report.controller;

import java.io.Serializable;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.ejianc.business.financeintegration.PMSalary.api.IPMSalarySystemApi;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzDetailVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.business.report.vo.ExportBankVO;
import com.ejianc.business.salary.bean.AcSetRelateEntity;
import com.ejianc.business.salary.service.IAcSetRelateService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.report.bean.SalaryListVWEntity;
import com.ejianc.business.report.service.ISalaryListVWService;
import com.ejianc.business.report.vo.SalaryListVWVO;

/**
 * 工资汇总表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("salaryListVW")
public class SalaryListVWController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private IPMSalarySystemApi salarySystemApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISalaryListVWService service;
    @Autowired
    private IAcSetRelateService acSetRelateService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SalaryListVWVO> saveOrUpdate(@RequestBody SalaryListVWVO saveOrUpdateVO) {
    	SalaryListVWEntity entity = BeanMapper.map(saveOrUpdateVO, SalaryListVWEntity.class);
    	service.saveOrUpdate(entity, false);
    	SalaryListVWVO vo = BeanMapper.map(entity, SalaryListVWVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SalaryListVWVO> queryDetail(Long id) {
    	SalaryListVWEntity entity = service.selectById(id);
    	SalaryListVWVO vo = BeanMapper.map(entity, SalaryListVWVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SalaryListVWVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SalaryListVWVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SalaryListVWVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SalaryListVWVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("detailEmployeeName");
        fuzzyFields.add("detailEmployeeCode");
        fuzzyFields.add("orgName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        if (param.getParams().containsKey("month")){
            String month = param.getParams().get("month").getValue().toString();
            String[] split = month.split(",");
            split[0] = split[0] + "-01";
            split[1] = split[1] + "-01";
            param.getParams().put("month",new Parameter(QueryParam.BETWEEN,split[0]+","+split[1]));
        }else if (param.getParams().containsKey("period")){
            String month = param.getParams().get("period").getValue().toString();
            String[] split = month.split(",");
            split[0] = split[0] + "-01";
            split[1] = split[1] + "-01";
            param.getParams().put("period",new Parameter(QueryParam.BETWEEN,split[0]+","+split[1]));
        }else {
            return CommonResponse.error("请在筛选条件中选择时间！");
        }
        IPage<SalaryListVWEntity> page = service.queryPage(param,false);
        IPage<SalaryListVWVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryListVWVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("detailEmployeeName");
        fuzzyFields.add("detailEmployeeCode");
        fuzzyFields.add("orgName");

        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SalaryListVWEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("SalaryListVW-export.xlsx", beans, response);
    }
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/excelBankExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelBankExport(@RequestBody QueryParam param, HttpServletResponse response) {

        param.setPageSize(200);
        if (! (param.getParams().containsKey("acCode"))){
            QueryParam queryParam = new QueryParam();
            queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
            queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            List<AcSetRelateEntity> acSetRelateEntities = acSetRelateService.queryList(queryParam);
            if (CollectionUtils.isNotEmpty(acSetRelateEntities)){
                List<String> collect = acSetRelateEntities.stream().map(p -> p.getAcSetCode()).collect(Collectors.toList());
                param.getParams().put("acCode",new Parameter(QueryParam.IN,collect));
            }
        }
        CommonResponse<JSONObject> commonResponse = salarySystemApi.queryGZList(param);
        if(!commonResponse.isSuccess()){
            throw new BusinessException("查询工资明细失败!");
        }
        JSONObject responseData = commonResponse.getData();
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        JSONArray records = responseData.getJSONArray("records");
        List<ExportBankVO> exportBankVOS = records.toJavaList(ExportBankVO.class);
        for (int i = 0; i < exportBankVOS.size(); i++) {
            String bankName = exportBankVOS.get(i).getBankName();
            //补充序号
            exportBankVOS.get(i).setSortNum(i+1);

            String yearMonth = exportBankVOS.get(i).getYearMonth();
            // 解析为 DateTime（自动补全为当月第一天）
            DateTime dateTime = new DateTime(yearMonth, "yyyyMM");
            // 格式化为 yyyy-MM-dd
            if(bankName.contains("浦东发展银行") || bankName.contains("浦发银行")){
                String formattedDate = dateTime.toString("yyyy-MM-dd");
                exportBankVOS.get(i).setYearMonth(formattedDate);

            } else {
                String formattedDate = dateTime.toString("yyyy/MM/dd");
                exportBankVOS.get(i).setYearMonth(formattedDate);
            }

        }
        beans.put("records", exportBankVOS);
        if(ListUtil.isNotEmpty(exportBankVOS)){
            String bankName = exportBankVOS.get(0).getBankName();
            logger.info("1-----------bankName{}",bankName);
            logger.info("2-----------records{}",responseData.get("records").toString());
            if(bankName.contains("浦东发展银行") || bankName.contains("浦发银行")){
                ExcelExport.getInstance().export("银企直连（代付）-浦发模版.xlsx", beans, response);
            }
            if(bankName.contains("农业银行")){
                ExcelExport.getInstance().export("银企直连（代付）-农行工资模版.xlsx", beans, response);
            }
            if(bankName.contains("郑州银行")){
                ExcelExport.getInstance().export("银企直连（代付）-郑州银行模版.xlsx", beans, response);
            }
            if(bankName.contains("交通银行")){
                ExcelExport.getInstance().export("网银-交行代发薪资模版.xlsx", beans, response);
            }
            if(bankName.contains("建设银行")){
                ExcelExport.getInstance().export("网银-建行工资模板.xlsx", beans, response);
            }
        }
        ExcelExport.getInstance().export("银企直连（代付）-郑州银行模版.xlsx", beans, response);

    }
    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refSalaryListVWData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SalaryListVWVO>> refSalaryListVWData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SalaryListVWEntity> page = service.queryPage(param,false);
        IPage<SalaryListVWVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryListVWVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/querySbList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> querySbList(@RequestBody QueryParam param) {
        return salarySystemApi.queryList(param);
    }
    @RequestMapping(value = "/queryGzList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryGzList(@RequestBody QueryParam param) {



        if (! (param.getParams().containsKey("acCode"))){
            QueryParam queryParam = new QueryParam();
            queryParam.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
            queryParam.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            List<AcSetRelateEntity> acSetRelateEntities = acSetRelateService.queryList(queryParam);
            if (CollectionUtils.isNotEmpty(acSetRelateEntities)){
                List<String> collect = acSetRelateEntities.stream().map(p -> p.getAcSetCode()).collect(Collectors.toList());
                param.getParams().put("acCode",new Parameter(QueryParam.IN,collect));
            }
        }
        return salarySystemApi.queryGZList(param);
    }


}
